@@ -1,15 +1,16 @@
 package NumSeq::Iter;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-01'; # DATE
-our $DIST = 'NumSeq-Iter'; # DIST
-our $VERSION = '0.004'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 
 use Exporter qw(import);
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-01-21'; # DATE
+our $DIST = 'NumSeq-Iter'; # DIST
+our $VERSION = '0.005'; # VERSION
+
 our @EXPORT_OK = qw(numseq_iter numseq_parse);
 
 my $re_num = qr/(?:[+-]?[0-9]+(?:\.[0-9]+)?)/;
@@ -89,9 +90,9 @@ sub _numseq_parse_or_iter {
     my $cur;
     my $ends;
     return sub {
-        return undef if $ends;
+        return undef if $ends; ## no critic: Subroutines::ProhibitExplicitReturnUndef
         return $nums[$i++] if $i <= $#nums;
-        if (!$has_ellipsis) { $ends++; return undef }
+        if (!$has_ellipsis) { $ends++; return undef } ## no critic: Subroutines::ProhibitExplicitReturnUndef
 
         $cur //= $nums[-1];
         if ($is_arithmetic) {
@@ -99,7 +100,7 @@ sub _numseq_parse_or_iter {
             if (defined $last_num) {
                 if ($inc >= 0 && $cur > $last_num || $inc < 0 && $cur < $last_num) {
                     $ends++;
-                    return undef;
+                    return undef; ## no critic: Subroutines::ProhibitExplicitReturnUndef
                 }
             }
             return $cur;
@@ -108,7 +109,7 @@ sub _numseq_parse_or_iter {
             if (defined $last_num) {
                 if ($inc >= 1 && $cur > $last_num || $inc < 1 && $cur < $last_num) {
                     $ends++;
-                    return undef;
+                    return undef; ## no critic: Subroutines::ProhibitExplicitReturnUndef
                 }
             }
             return $cur;
@@ -148,7 +149,7 @@ NumSeq::Iter - Generate a coderef iterator from a number sequence specification
 
 =head1 VERSION
 
-This document describes version 0.004 of NumSeq::Iter (from Perl distribution NumSeq-Iter), released on 2021-08-01.
+This document describes version 0.005 of NumSeq::Iter (from Perl distribution NumSeq-Iter), released on 2022-01-21.
 
 =head1 SYNOPSIS
 
@@ -157,10 +158,16 @@ This document describes version 0.004 of NumSeq::Iter (from Perl distribution Nu
   my $iter = numseq_iter('1,3,5,...,13');
   while (my $val = $iter->()) { ... } # 1,3,5,7,9,11,13
 
-  my $res = numseq_parse(''); # [400, "Parse fail: Please specify one or more number in number sequence"]
-  my $res = numseq_parse('1,3,5');        # [200, "OK", {numbers=>[1,2,3], has_ellipsis=>0, type=>'arithmetic', inc=>2}]
-  my $res = numseq_parse('1,3,9,...');    # [200, "OK", {numbers=>[1,3,9], has_ellipsis=>1, last_number=>undef, type=>'geometric', inc=>3}]
-  my $res = numseq_parse('1,3,5,...,10'); # [200, "OK", {numbers=>[1,2,3], has_ellipsis=>1, last_number=>10, type=>'arithmetic', inc=>2}]
+  $iter = numseq_iter('1,3,5,...,10');
+  while (my $val = $iter->()) { ... } # 1,3,5,7,9
+
+  my $res = numseq_parse('');             # [400, "Parse fail: Please specify one or more number in number sequence: ''"]
+  my $res = numseq_parse('1,5,2');        # [200, "OK", {numbers=>[1,5,2], has_ellipsis=>0, type=>'itemized', inc=>undef}]
+  my $res = numseq_parse('1,2,3');        # [200, "OK", {numbers=>[1,2,3], has_ellipsis=>0, type=>'itemized', inc=>undef}]
+  my $res = numseq_parse('1,2,3,...');    # [200, "OK", {numbers=>[1,2,3], has_ellipsis=>1, type=>'arithmetic', inc=>1, last_number=>undef}]
+  my $res = numseq_parse('1,3,9,...');    # [200, "OK", {numbers=>[1,3,9], has_ellipsis=>1, type=>'geometric',  inc=>3, last_number=>undef}]
+  my $res = numseq_parse('1,3,5,...,13'); # [200, "OK", {numbers=>[1,3,5], has_ellipsis=>1, type=>'arithmetic', inc=>2, last_number=>13}]
+  my $res = numseq_parse('2,3,5,...');    # [400, "Parse fail: Can't determine the pattern from number sequence: 2, 3, 5"]
 
 =head1 DESCRIPTION
 
@@ -208,14 +215,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/NumSeq-Ite
 
 Source repository is at L<https://github.com/perlancar/perl-NumSeq-Iter>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=NumSeq-Iter>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 Other iterators: L<IntRange::Iter>, L<Range::Iter>
@@ -231,11 +230,36 @@ Raku's lazy lists.
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2021 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=NumSeq-Iter>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
